@@ -5,7 +5,9 @@
 #include <stdlib.h>
 #include <string.h>
 
-#define GETNEXT getchar
+#ifndef GETNEXT
+#define GETNEXT getchar_unlocked
+#endif
 
 #include "json.h"
 
@@ -91,7 +93,7 @@ capacity(char **value, size_t *sz, size_t cur, size_t inc)
 int
 parsejson(void (*cb)(struct json_node *, size_t, const char *))
 {
-	struct json_node nodes[JSON_MAX_NODE_DEPTH] = { 0 };
+	struct json_node nodes[JSON_MAX_NODE_DEPTH] = { { 0 } };
 	size_t depth = 0, p = 0, len, sz = 0;
 	long cp, hi, lo;
 	char pri[128], *str = NULL;
