@@ -1,6 +1,5 @@
 #include <ctype.h>
 #include <errno.h>
-#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -43,12 +42,13 @@ processnode(struct json_node *nodes, size_t depth, const char *value)
 		printvalue(nodes[i].name);
 
 		if (i + 1 == depth &&
-		    (nodes[i].type == TYPE_OBJECT || nodes[i].type == TYPE_ARRAY))
+		    (nodes[i].type == JSON_TYPE_OBJECT ||
+		     nodes[i].type == JSON_TYPE_ARRAY))
 			continue;
 
-		if (nodes[i].type == TYPE_OBJECT) {
+		if (nodes[i].type == JSON_TYPE_OBJECT) {
 			putchar('.');
-		} else if (nodes[i].type == TYPE_ARRAY) {
+		} else if (nodes[i].type == JSON_TYPE_ARRAY) {
 			if (nflag) {
 				printf("[%zu]", nodes[i].index);
 			} else {
@@ -65,6 +65,13 @@ processnode(struct json_node *nodes, size_t depth, const char *value)
 	putchar('\n');
 }
 
+void
+usage(const char *argv0)
+{
+	fprintf(stderr, "usage: %s [-n] [-r]\n", argv0);
+	exit(1);
+}
+
 int
 main(int argc, char *argv[])
 {
@@ -76,12 +83,13 @@ main(int argc, char *argv[])
 	}
 
 	for (i = 1; i < argc; i++) {
-		if (argv[i][0] != '-')
-			continue;
+		if (argv[i][0] != '-' || argv[i][1] == '\0')
+			usage(argv[0]);
 		for (j = 1; argv[i][j]; j++) {
 			switch (argv[i][j]) {
 			case 'n': nflag = 1; break;
 			case 'r': rflag = 1; break;
+			default: usage(argv[0]); break;
 			}
 		}
 	}
